SystemOrganization addCategory: #'Seaside-Tests-Flow-Functional'!
SystemOrganization addCategory: #'Seaside-Tests-Flow-Unit'!

WAFunctionalTest subclass: #WACallDuringRenderFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WACallDuringRenderFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/28/2008 10:15'!
renderContentOn: html
	html paragraph: [
		html anchor
			callback: [ self call: WACallDuringRenderTestComponent new ];
			with: 'This link'.
		html text: ' will call a Component which attempts to do a #call: in its #renderContentOn: method. This is not allowed and should trigger a descriptive error. With WAWalkbackErrorHandler enabled, the output should explain to the user the likely cause of the problem.' ]! !

WAFunctionalTest subclass: #WAFlowFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WAFlowFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:32'!
goAnchors
	| component |
	1 to: 5 do: [ :each | 
		component := WAComponent new.
		component addMessage: [ :html | 
			html anchor
				callback: [ component answer ];
				with: each seasideString , ': ' , self stackDepth seasideString ] fixCallbackTemps.
		self call: component ]! !

!WAFlowFunctionalTest methodsFor: 'actions' stamp: 'pmm 8/31/2008 14:33'!
goButtons
	1 to: 5 do: [ :each |
		self inform: each seasideString, ': ', self stackDepth seasideString ]! !

!WAFlowFunctionalTest methodsFor: 'rendering' stamp: 'lr 5/22/2007 18:10'!
renderContentOn: html
	html paragraph: 'The following two anchors should trigger flows with 5 steps each. The stack should neither grow nor shrink. Backtracking and spawning of windows should properly work.'.
	html paragraph: [
		html anchor
			callback: [ self goAnchors ];
			with: 'go anchors'.
		html break.
		html anchor
			callback: [ self goButtons ];
			with: 'go buttons' ]! !

!WAFlowFunctionalTest methodsFor: 'private' stamp: 'jf 1/22/2009 02:43'!
stackDepth

	^WAPlatform current stackDepth! !

!WAPackage class methodsFor: '*seaside-tests-flow' stamp: 'jf 1/27/2009 11:34'!
seasideTestsFlow
	^ self new
		name: 'Seaside-Tests-Flow';
		description: 'Functional tests for Seaside-Flow.';
		addDependency: 'Seaside-Flow';
		addDependency: 'Seaside-Tests-Functional';
		yourself! !

WAComponent subclass: #WACallDuringRenderTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WACallDuringRenderTestComponent methodsFor: 'rendering' stamp: 'jf 10/28/2008 10:13'!
renderContentOn: html
	self call: WAMiniCalendar new! !

WATask subclass: #WADecorationTask
	instanceVariableNames: 'component1 component2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WADecorationTask methodsFor: 'accessing' stamp: 'lr 11/28/2008 16:40'!
children
	"Even if we component1 and component2, we have to return them as children as otherwise their decorations are not properly backtracked. See WADecorationTest."
	
	^ Array with: component1 with: component2! !

!WADecorationTask methodsFor: 'running' stamp: 'lr 5/31/2008 10:36'!
go
	self call: component1.
	self call: component2! !

!WADecorationTask methodsFor: 'initialization' stamp: 'lr 5/31/2008 15:53'!
initialize
	super initialize.
	component1 := WAFormDialog new
		addMessage: 'Step 1';
		yourself.
	component2 := WAFormDialog new
		addMessage: 'Step 2';
		yourself! !

WATask subclass: #WAFunctionalTaskTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

WAFunctionalTaskTest subclass: #WAConvenienceFunctionalTest
	instanceVariableNames: 'cheese'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
chooseCheese
	cheese := self
		chooseFrom: #('Greyerzer' 'Tilsiter' 'Sbrinz')
		caption: 'What''s your favorite Cheese?'.
	cheese isNil ifTrue: [ self chooseCheese ]! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
confirmCheese
	^self confirm: 'Is ', cheese,  ' your favorite cheese?'! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'pmm 6/30/2007 12:24'!
go
	[ self chooseCheese.
	  self confirmCheese ] whileFalse.
	self informCheese! !

!WAConvenienceFunctionalTest methodsFor: 'controlling' stamp: 'lr 10/28/2007 14:42'!
informCheese
	self inform: 'Your favorite cheese is ', cheese, '.'! !

!WAConvenienceFunctionalTest methodsFor: 'accessing' stamp: 'pmm 8/29/2008 16:05'!
states
	^Array with: self! !

WAFunctionalTaskTest subclass: #WAExceptionFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WAExceptionFunctionalTest methodsFor: 'processing' stamp: 'pmm 11/1/2007 21:32'!
go
	[ (self confirm: 'Raise an exception?')
		ifTrue: [ self error: 'foo' ] ]
			on: Error
			do: [ :error | self inform: 'Caught: ', error description ]! !

WATask subclass: #WANestedTransaction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Functional'!

!WANestedTransaction commentStamp: 'pmm 9/2/2007 00:08' prior: 0!
A WANestedTransaction is a test that uses two nested #isolate: blocks!

!WANestedTransaction methodsFor: 'processing' stamp: 'lr 10/28/2007 14:42'!
go
	self inform: 'Before parent txn'.
	self isolate:
			[self inform: 'Inside parent txn'.
			self isolate: [self inform: 'Inside child txn'].
			self inform: 'Outside child txn'].
	self inform: 'Outside parent txn'! !

TestCase subclass: #WAFlowPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Flow-Unit'!

!WAFlowPlatformTest methodsFor: 'private' stamp: 'jf 1/27/2009 14:21'!
evaluateCallbackContinuation: aContinuation with: anObject
	| callback |
	callback := WAActionCallback new.
	callback block: [ aContinuation value: anObject ].
	[ callback evaluateWithArgument: nil ]
		on: WARenderNotification do: [ :n | ]! !

!WAFlowPlatformTest methodsFor: 'testing' stamp: 'jf 1/27/2009 14:20'!
testSuspendCallbackDo
	| continuation result |
	continuation := nil.
	self withCallbackContinuationDo: [ :cc | continuation := cc ] resultBlock: [ :r | result := r ].
	self assert: continuation notNil.
	self evaluateCallbackContinuation: continuation with: 123.
	self assert: result = 123! !

!WAFlowPlatformTest methodsFor: 'private' stamp: 'jf 1/27/2009 14:20'!
withCallbackContinuationDo: ccBlock resultBlock: resultBlock
	| callback |
	callback := WAActionCallback new.
	callback block: [
		resultBlock value: (WAPlatform current suspendCallbackDo: ccBlock) ].
	[ callback evaluateWithArgument: nil ]
		on: WARenderNotification do: [ :n | ].! !
